@@ -1,27 +1,14 @@
 /*
- * This file is part of the KDE Libraries
- * Copyright (C) 2000 Espen Sand (espen@kde.org)
- * Copyright (C) 2006 Nicolas GOUTTE <goutte@kde.org>
- * Copyright (C) 2008 Friedrich W. H. Kossebau <kossebau@kde.org>
- * Copyright (C) 2010 Teo Mrnjavac <teo@kde.org>
- * Copyright (C) 2017 Harald Sitter <sitter@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- */
+    This file is part of the KDE Libraries
+
+    SPDX-FileCopyrightText: 2000 Espen Sand <espen@kde.org>
+    SPDX-FileCopyrightText: 2006 Nicolas GOUTTE <goutte@kde.org>
+    SPDX-FileCopyrightText: 2008 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2010 Teo Mrnjavac <teo@kde.org>
+    SPDX-FileCopyrightText: 2017 Harald Sitter <sitter@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kaboutdata.h"
 #include "kpluginmetadata.h"
@@ -44,7 +31,7 @@
 
 Q_DECLARE_LOGGING_CATEGORY(KABOUTDATA)
 // logging category for this framework, default: log stuff >= warning
-Q_LOGGING_CATEGORY(KABOUTDATA, "kf5.kcoreaddons.kaboutdata", QtWarningMsg)
+Q_LOGGING_CATEGORY(KABOUTDATA, "kf.coreaddons.kaboutdata", QtWarningMsg)
 
 
 class Q_DECL_HIDDEN KAboutPerson::Private
@@ -302,7 +289,7 @@ QString KAboutLicense::text() const
 
     if (knownLicense) {
         pathToFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                QString::fromLatin1("kf5/licenses/") + pathToFile);
+                QLatin1String("kf5/licenses/") + pathToFile);
         result += QCoreApplication::translate(
                       "KAboutLicense",
                       "This program is distributed under the terms of the %1.").arg(name(KAboutLicense::ShortName));
@@ -474,7 +461,9 @@ public:
     QList<KAboutPerson> _translatorList;
     QList<KAboutLicense> _licenseList;
     QString productName;
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 2)
     QString programIconName;
+#endif
     QVariant programLogo;
     QString customAuthorPlainText, customAuthorRichText;
     bool customAuthorTextEnabled;
@@ -573,7 +562,7 @@ KAboutData::KAboutData(const QString &_componentName,
     d->organizationDomain = QStringLiteral("kde.org");
     // KF6: do not set a default desktopFileName value here, but remove this code and leave it empty
     // see KAboutData::desktopFileName() for details
-    d->desktopFileName = QStringLiteral("org.kde.%1").arg(d->_componentName);
+    d->desktopFileName = QLatin1String("org.kde.") + d->_componentName;
 }
 
 KAboutData::~KAboutData()
@@ -606,17 +595,21 @@ KAboutData &KAboutData::operator=(const KAboutData &other)
     return *this;
 }
 
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 65)
 KAboutData KAboutData::fromPluginMetaData(const KPluginMetaData &plugin)
 {
     KAboutData ret(plugin.pluginId(), plugin.name(), plugin.version(), plugin.description(),
                    KAboutLicense::byKeyword(plugin.license()).key(), plugin.copyrightText(),
                    plugin.extraInformation(), plugin.website());
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 2)
     ret.d->programIconName = plugin.iconName();
+#endif
     ret.d->_authorList = plugin.authors();
     ret.d->_translatorList = plugin.translators();
     ret.d->_creditList = plugin.otherContributors();
     return ret;
 }
+#endif
 
 
 KAboutData &KAboutData::addAuthor(const QString &name,
@@ -815,6 +808,7 @@ const char *KAboutData::internalProgramName() const
     return d->_internalProgramName.constData();
 }
 
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 2)
 QString KAboutData::programIconName() const
 {
     return d->programIconName.isEmpty() ? componentName() : d->programIconName;
@@ -825,6 +819,7 @@ KAboutData &KAboutData::setProgramIconName(const QString &iconName)
     d->programIconName = iconName;
     return *this;
 }
+#endif
 
 QVariant KAboutData::programLogo() const
 {
@@ -899,15 +894,19 @@ QList<KAboutPerson> KAboutData::credits() const
 QList<KAboutPerson> KAboutData::Private::parseTranslators(const QString &translatorName, const QString &translatorEmail)
 {
     QList<KAboutPerson> personList;
-    if (translatorName.isEmpty() || translatorName == QStringLiteral("Your names")) {
+    if (translatorName.isEmpty() || translatorName == QLatin1String("Your names")) {
         return personList;
     }
 
     const QStringList nameList(translatorName.split(QLatin1Char(',')));
 
     QStringList emailList;
-    if (!translatorEmail.isEmpty() && translatorEmail != QStringLiteral("Your emails")) {
+    if (!translatorEmail.isEmpty() && translatorEmail != QLatin1String("Your emails")) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         emailList = translatorEmail.split(QLatin1Char(','), QString::KeepEmptyParts);
+#else
+        emailList = translatorEmail.split(QLatin1Char(','), Qt::KeepEmptyParts);
+#endif
     }
 
     QStringList::const_iterator nit;
@@ -1182,9 +1181,9 @@ void KAboutData::processCommandLine(QCommandLineParser *parser)
         } else {
             printf("%s\n", qPrintable(QCoreApplication::translate("KAboutData CLI", "%1 was written by:").arg(qAppName())));
             for (const KAboutPerson &person : qAsConst(d->_authorList)) {
-                QString authorData = QStringLiteral("    ") + person.name();
+                QString authorData = QLatin1String("    ") + person.name();
                 if (!person.emailAddress().isEmpty()) {
-                    authorData.append(QStringLiteral(" <") + person.emailAddress() + QStringLiteral(">"));
+                    authorData.append(QLatin1String(" <") + person.emailAddress() + QLatin1Char('>'));
                 }
                 printf("%s\n", qPrintable(authorData));
             }
